=====================================
Review Board 1.6 Beta 2 Release Notes
=====================================


**Release date**: May 9, 2011


This release contains all bug fixes and features found in
Review Board version :doc:`1.5.5 <1.5.5>`.


Important Upgrade Notes
=======================

* The generated settings_local.py file for new sites in 1.6 beta 1 had
  a shortened version of the database engine path (stored in ``ENGINE``).
  This is deprecated. We now generate the full path.

  Sites created in 1.6 beta 1 may need adjustment to be compatible with
  future versions of Django. Locate the line with ``'ENGINE:' '<name>'`` and
  prefix ``django.db.backends.`` before ``<name>``.


New Features
============

* Added basic issue tracking support for comments and reviews.

  This provides a new and improved way to mark and reply to defects in
  a change. When reviewing code, a reviewer can mark a comment as a defect,
  and when the developer makes the fix they can simply mark the defect
  as fixed. Or, they can choose to drop it.

  This speeds up the review process. There's less typing needed, and
  down the road, we can provide a quick summary of all the changes that
  are needed or that have been fixed.

  Patch by Mike Conley.

* Added a quick search field.

  The search field is now always shown, and will search as you type.
  Unlike the full-text search (which will happen when clicking Search, if
  full-text search is enabled), this will only search users (by username,
  first name or last name), groups (group name or display name), or
  review requests (numeric ID or summary).

  Patch by Crystal Lok Koo. (:bug:`1842`)

* Review draft banners now stay on screen while the review is shown.

  This helps with long reviews when you've reached a point where you want
  to publish the review. You no longer need to scroll up to find the
  draft banner. It will remain on screen.

  Patch by Mark Striemer.

* Added support for e-mailing administrators when new users register.

  Administrators can be notified when new users sign up on the Review Board
  server. This is particularly useful for open source projects.

  Patch by Hongbin Lu. (:bug:`1081`)

* Added move/rename information in the diff viewer.

  The change index and file sections now show when a file has been moved
  or renamed and what the new name is. Whether or not this is shown depends
  on the diff and type of repository. Patch by Colin Caughie.

* Added support for copy/rename information in git-style diffs on Mercurial.
  Patch by Colin Caughie.

* Added ``X-ReviewGroup`` headers for e-mails, improving e-mail filtering.
  Patch by Vignesh Srinivasan. (:bug:`1964`)

* Added a brand new Clear Case implementation.

  This new implementation is cleaner, more reliable, and fixes many of the
  problems with the old implementation. Given that this is a complete
  rewrite, we'd appreciate any bug reports for things that used to work
  in Review Board 1.5.x.

  Patch by Jan Koprowski. (:bug:`1375`, :bug:`1516`, :bug:`1553`,
  :bug:`1588`, :bug:`1599`, :bug:`1644`, :bug:`1727`, :bug:`1926`,
  :bug:`1930`, :bug:`1931`).

* SSH keys can now be defined per-Local Site. This means if a server has
  a Review Board instance partitioned into two Local Sites, each can have
  their own SSH keys configured.

  This has implications on the SCMTools API. SCMTools that provide
  check_repository or accept_certificate functions now need to accept
  ``local_site_name`` parameters.


Removed Features
================

* Removed RSS/Atom feed support.

  In the very early days, we had RSS/Atom feeds for review requests, users
  and groups. These aren't really useful anymore, and nothing has ever
  truly exposed them. Most likely, nobody even knows they exist. They're
  now gone.


API Changes
===========

* Added API for getting change descriptions.

  All the information from the change descriptions can now be retrieved.
  They contain more information than even the change descriptions on the
  website. Users, screenshots, and other such resource-backed data now
  embeds and links to the appropriate resource. (:bug:`2026`)

* Added a quick search API for retrieving basic searchable information.

  A ``/search/?q=`` resource has been added that can search for various
  bits of information based on search terms. It will search users
  (matching username, first name, and last name), groups (name and display
  name), and review requests (IDs and summaries).

  Patch by Crystal Lok Koo.

* Draft resources weren't always being fetched correctly, returning 404s.

* Links in resources on Local Sites are no longer broken.


Bug Fixes
=========

* Fixed compatibility with Django 1.3.

  A Django 1.3 beta compatibility fix was introduced in Review Board 1.6
  beta 1, which was no longer needed nor worked with the final Django 1.3
  release. We've reverted that original fix.

* The groups box in the user preferences page is no longer displayed if
  there are no groups to join. Patch by Steve Sutcliffe. (:bug:`1233`)

* Increased the size of the text field son the New Review Request page.
  They're now the width of the page. Patch by Mengyun Kong. (:bug:`1571`)

* Git patches containing new or deleted files would not have all the
  information preserved in the downloaded diff. (:bug:`1715`)

* Saving a review request in the admin UI no longer fails due to a blank
  Local ID field. (:bug:`2003`)

* Table captions in the admin dashboard were scrambled on Google Chrome.
  Patch by Vignesh Srinivasan. (:bug:`2017`)

* Review Board no longer breaks when set up with mod_wsgi without mod_python
  installed. (:bug:`2023`)

* The starred reviews counts weren't incremented properly. This would cause
  removing a star to show a negative count in the dashboard. Patch by Vignesh
  Srinivasan. (:bug:`2029`)

* The incoming group counts on the dashboard weren't always updated properly.
  Patch by Vignesh Srinivasan. (:bug:`2032`)

* Both the groups and people reviewer auto-complete lists now have a
  "Press Tab to auto-complete" footer at the bottom of the list. Previously,
  only one of the lists had this.

* Fixed a breakage when reporting errors on failed diffs.

* The proper user information on the user page wasn't correct. The logged in
  user was being shown instead of the user represented by the URL.

* Newly uploaded screenshots are no longer shown on the review request until
  the draft is published. Since 1.0, we've always shown whether or not they
  were intended to be public.

* Draft captions for screenshots are now properly displayed on the review
  request page. Previously, we'd show the original caption.

* Editing a caption for a screenshot properly saves it again.

* The order of values in the change descriptions were seemingly random.
  This affected such fields as bug numbers and reviewers. Now they maintain
  the order shown in the actual fields.

* Fixed a usability problem with the user infobox.

  The infobox would appear as soon as the mouse hovered over a user. Now we
  have a one second delay.

* Fixed visual issues in the user infobox on Google Chrome.

* Fixed several problems with commenting and saving reviews.


Contributors
============

* Christian Hammond
* Colin Caughie
* Crystal Lok Koo
* David Trowbridge
* Hongbin Lu
* Jan Koprowski
* Mark Striemer
* Mengyun Kong
* Mike Conley
* Philipp Henkel
* Steve Sutcliffe
* Vignesh Srinivasan
